DeveloperModel class

Constructors

DeveloperModel({required String id, required String email, required String fullName, required String plan, required DateTime createdAt, DateTime? deletedAt, DateTime? updatedAt})
DeveloperModel.fromMap(Map<String, dynamic> map)
factory

Properties

createdAt DateTime
final
deletedAt DateTime?
final
email String
final
fullName String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
plan String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited