ProjectConfig class

Constructors

ProjectConfig({SkinModel? skin, String? projectId, String? teamId, String? projectName})
ProjectConfig.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
projectId String?
final
projectName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skin SkinModel?
final
teamId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited