ProjectModel class

Constructors

ProjectModel({required String id, required String developerId, required String appName, required String description, required String activeSkinId, required DateTime createdAt, required DateTime updatedAt, DateTime? deletedAt})
ProjectModel.fromMap(Map<String, dynamic> map)
factory

Properties

activeSkinId String
final
appName String
final
createdAt DateTime
final
deletedAt DateTime?
final
description String
final
developerId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited