remote/fskin_remote_config library

Classes

FskinRemoteConfig
Singleton class responsible for managing the remote configuration of the skin. It fetches the configuration from the remote server using the provided API key and caches it for subsequent access.