FskinRemoteConfig class

Singleton class responsible for managing the remote configuration of the skin. It fetches the configuration from the remote server using the provided API key and caches it for subsequent access.

Properties

apiKey String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchConfig() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

projectConfig ProjectConfig?
no setter
singleton FskinRemoteConfig
no setter

Static Methods

init({required String apiKey}) Future<FskinRemoteConfig>