fetchConfig method
Implementation
Future<void> fetchConfig() async {
// Call the skin service to fetch skin for developer and project
//final skin = await SkinService().getSkin(apiKey);
_cachedConfig = await SkinService().fetchData(apiKey);
}
Future<void> fetchConfig() async {
// Call the skin service to fetch skin for developer and project
//final skin = await SkinService().getSkin(apiKey);
_cachedConfig = await SkinService().fetchData(apiKey);
}