CacheService class

Constructors

CacheService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedPreferences Future<SharedPreferences>
final

Methods

getApiKey() Future<String?>
getLastUpdated() Future<DateTime?>
getProjectConfig() Future<ProjectConfig?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveApiKey(String apiKey) Future<void>
saveProjectConfig(Map<String, dynamic> projectConfig) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited