services/skin_service library

Classes

SkinService
Singleton service class responsible for fetching the skin configuration from the remote server. This class abstracts the network communication and provides a method to retrieve the ProjectConfig