SkinModel class
Constructors
- SkinModel({required String id, required String projectId, required bool isActive, required int version, required DateTime createdAt, required ColorScheme? colors, DateTime? publishedAt, DateTime? deletedAt})
-
SkinModel.fromMap(Map<
String, dynamic> map) -
Factory constructor to create SkinModel from a map
factory
Properties
- colors → ColorScheme?
-
final
- createdAt → DateTime
-
final
- deletedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isActive → bool
-
final
- projectId → String
-
final
- publishedAt → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromSchemaString(
Map< String, dynamic> schemaString) → SkinModel? - Parse SkinModel from schema string (JSON format)