SkinService class
Singleton service class responsible for fetching the skin configuration from the remote server. This class abstracts the network communication and provides a method to retrieve the ProjectConfig
Constructors
- SkinService()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchData(
String apiKey) → Future< ProjectConfig?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited